@@ -1,3 +1,5 @@
+import sys
+
 import pytest
 import colorcet as cc
 
@@ -44,5 +46,9 @@ def test_matplotlib_default_colormap_plot_kbc():
 
 @pytest.mark.parametrize('k,v', list(cc.cm.items()))
 def test_get_cm(k, v):
-    import matplotlib.cm as mcm
-    assert mcm.get_cmap('cet_' + k) is v
+    if sys.version_info < (3, 7):
+        import matplotlib.cm as mcm
+        assert mcm.get_cmap('cet_' + k) is v
+    else:
+        from matplotlib import colormaps
+        assert colormaps['cet_' + k] == v
